# -*- coding: utf-8 -*-
import os
import numpy as np
from matplotlib.axes import Axes
from dspawpy.io.read import get_band_data, get_dos_data
from pymatgen.electronic_structure.plotter import BSDOSPlotter

bandfile = "dspawpy_proj/dspawpy_tests/inputs/2.3/band.h5"  # 普通能带数据
band_data = get_band_data(
    band_dir=bandfile,
    syst_dir=None,  # system.json文件路径，仅当band_dir为json文件时需要
    efermi=None,  # 用于手动修正费米能级
    zero_to_efermi=True,  # 非金属体系应将零点能移动到费米能级
)
dosfile = "dspawpy_proj/dspawpy_tests/inputs/2.5/dos.h5"  # 态密度数据
dos_data = get_dos_data(
    dos_dir=dosfile,
    return_dos=False,  # 如果为False，则统一返回CompleteDos对象（无论计算时是否开了投影）
)
bdp = BSDOSPlotter(
    bs_projection="elements",  # 能带的投影方式，None表示不投影
    dos_projection=None,  # 态密度的投影方式，None表示不投影
    vb_energy_range=4,  # 价带能量范围
    cb_energy_range=4,  # 导带能量范围
    fixed_cb_energy=False,  # 是否固定导带能量范围
    egrid_interval=1,  # 能量格点间隔
    font="DejaVu Sans",  # 默认Times New Roman，修改成 DejaVu Sans，可避免在linux上因字体未安装而出现的警告
    axis_fontsize=20,  # 坐标轴字体大小
    tick_fontsize=15,  # 刻度字体大小
    legend_fontsize=14,  # 图例字体大小
    bs_legend="best",  # 能带图图例位置
    dos_legend="best",  # 态密度图图例位置
    rgb_legend=True,  # 是否使用彩色图例
    fig_size=(11, 8.5),  # 图片大小
)
axes_or_plt = bdp.get_plot(bs=band_data, dos=dos_data)  # 传入能带数据  # 传入态密度数据

if isinstance(axes_or_plt, Axes):
    fig = axes_or_plt.get_figure()  # version newer than v2023.8.10
elif np.iterable(axes_or_plt):
    fig = np.asarray(axes_or_plt).flatten()[0].get_figure()
else:
    fig = axes_or_plt.gcf()  # older version pymatgen

filename = (
    "dspawpy_proj/dspawpy_tests/outputs/us/6bandDos.png"  # 输出的能带-态密度图文件名
)
os.makedirs(os.path.dirname(os.path.abspath(filename)), exist_ok=True)
fig.savefig(filename, dpi=300)
